<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* KnowledgeBase homepage
*
* Displays a knowledgebase homepage. 
*
* @package KnowledgeBase
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: search.php,v 1.6 2007/07/30 01:57:03 glendavies Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../../local/config.inc.php');
require_once($CONFIG['LANGUAGE_CPATH'].'/kb_strings.inc.php');
require_once('lib.inc.php');


//set the required variables

if ($_SERVER['REQUEST_METHOD']=='GET') {

	$module_key	= $_GET['module_key'];
	$group_key	= $_GET['group_key'];
	$message	= $_GET['message'];
	$search_terms = $_GET['search_terms'];
	
} 
$space_key 	= get_space_key();
$link_key 	= get_link_key($module_key,$space_key);

//check we have the required variables
check_variables(true,true,true);

//check to see if user is logged in. 
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];
$group_access = $access_levels['groups'];
$group_accesslevel = $access_levels['group_accesslevel'][$group_key];
$is_admin = check_module_edit_rights($module_key);

$objKb = new InteractKB($space_key, $module_key, $group_key, $is_admin, $kb_strings);
$kb_data = $objKb->getKbData($module_key);

require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(

	'header'	 	=> 'header.ihtml',
	'navigation' 	=> 'navigation.ihtml',
	'body'	   		=> 'kb/search.ihtml',
	'footer'	 	=> 'footer.ihtml'

));

// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);
set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);

$t->set_var('MODULE_KEY',$module_key);

if ($is_admin!=true) {

	$t->set_block('body', 'KBAdminlinksBlock', 'KBABlock');
	$t->set_var('KBABlock','');


}
$t->parse('CONTENTS', 'header', true); 
get_navigation();


//now get any entries without a category
$t->set_block('body', 'EntrylinksBlock', 'ELSBlock');
$t->set_block('body', 'TemplateTypeBlock', 'TTBlock');
$search_limit = $objKb->createSearchLimit($search_terms);
$rs = $CONN->Execute("SELECT DISTINCT {$CONFIG['DB_PREFIX']}kb_entries.entry_key, {$CONFIG['DB_PREFIX']}kb_entries.template_key, {$CONFIG['DB_PREFIX']}kb_templates.name, {$CONFIG['DB_PREFIX']}kb_entries.added_by_key, {$CONFIG['DB_PREFIX']}kb_entries.status_key FROM {$CONFIG['DB_PREFIX']}kb_entries, {$CONFIG['DB_PREFIX']}kb_entry_data, {$CONFIG['DB_PREFIX']}kb_templates, {$CONFIG['DB_PREFIX']}users WHERE {$CONFIG['DB_PREFIX']}kb_entries.entry_key={$CONFIG['DB_PREFIX']}kb_entry_data.entry_key  AND  {$CONFIG['DB_PREFIX']}kb_entries.template_key={$CONFIG['DB_PREFIX']}kb_templates.template_key AND {$CONFIG['DB_PREFIX']}kb_entries.added_by_key={$CONFIG['DB_PREFIX']}users.user_key AND {$CONFIG['DB_PREFIX']}kb_entries.module_key='$module_key' AND $search_limit ORDER BY {$CONFIG['DB_PREFIX']}kb_templates.name");

echo $CONN->ErrorMsg();
if ($rs->EOF) {

	$t->set_var('ELSBlock',sprintf($general_strings['no_results'], '<em>'.$search_terms.'</em>'));
	$t->parse('TTBlock', 'TemplateTypeBlock', true);
	
} else {

	$n=0;
	$field_array=array();
	$entries_array=array();
	$template_type='';
	$template_count = $objKb->countTemplates($module_key);
	
	while (!$rs->EOF) {
	
		$t->set_var('ELSBlock','');
		
		$entry_key 		= $rs->fields[0];
		$template_key 	= $rs->fields[1];
		$template_type  = $rs->fields[2];
		$added_by_key  	= $rs->fields[3];
		$status_key  	= $rs->fields[4];
		
		if ($status_key==2 || (isset($_SESSION['current_user_key']) && $added_by_key==$_SESSION['current_user_key'])) {
				
			$summary_fields = $objKb->getsummary_fields($entry_key, $template_key, $category_key);
			$entries_array[$n] = $summary_fields['fields'];
			$n++;
			
		}
		

		$rs->MoveNext();
	
	}

	natcasesort($field_array);
	$t->set_var('ELSBlock','');			
	foreach ($entries_array as $value) {
	
		$t->set_var('SUMMARY_FIELDS',$value);
		$t->parse('ELSBlock', 'EntrylinksBlock', true);
		
	}


	$t->parse('TTBlock', 'TemplateTypeBlock', true);

}
$t->set_strings('body',  $kb_strings, '', '');
$t->parse('CONTENTS', 'body', true);
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p('CONTENTS');

$CONN->Close();	   
exit;	
?>
